@@ -95,7 +95,7 @@ static string submit_str   = "\n<INPUT TYPE=\"submit\" VALUE=\"Submit Form\">\n<
 static string input_str    = "<INPUT";
 static string select_str   = "<SELECT";
 static string end_sel_str  = "</SELECT";
-static string option_str   = "<OPTION";
+//static string option_str   = "<OPTION";
 static string textarea_str = "<TEXTAREA";
 static string textend_str  = "</TEXTAREA";
 static string checked      = "CHECKED";
@@ -105,12 +105,21 @@ static string selected     = "SELECTED";
 static string value_str    = "VALUE=\"";
 static string name_str     = "NAME=\"";
 
-static string text_type_str = "TYPE=\"TEXT\"";
-static string radio_type_str = "TYPE=\"RADIO\"";
-static string checkbox_type_str = "TYPE=\"CHECKBOX\"";
-static string password_type_str = "TYPE=\"PASSWORD\"";
+static string text_type_str =      "TYPE=\"TEXT\"";
+static string radio_type_str =     "TYPE=\"RADIO\"";
+static string checkbox_type_str =  "TYPE=\"CHECKBOX\"";
+static string password_type_str =  "TYPE=\"PASSWORD\"";
+static string number_str =    "TYPE=\"NUMBER\"";
+static string date_str =           "TYPE=\"DATE\"";
+static string datetime_str =       "TYPE=\"DATETIME\"";
+static string datetime_local_str = "TYPE=\"DATETIME-LOCAL\"";
+static string time_str =           "TYPE=\"TIME\"";
+static string week_str =           "TYPE=\"WEEK\"";
+static string month_str =          "TYPE=\"MONTH\"";
 
-enum {T_TEXT, T_RADIO, T_CHECKBOX, T_AREA, T_SELECT, T_OPTION, T_PASSWORD};
+enum {
+	T_TEXT, T_RADIO, T_CHECKBOX, T_AREA, T_SELECT, T_PASSWORD,
+	T_NUMBER, T_DATE, T_DTIME, T_DTIME_LOCAL, T_TIME, T_WEEK, T_MONTH };
 
 struct INPUT_TYPE {
 	int id;
@@ -127,8 +136,14 @@ static INPUT_TYPE input_types[] = {
 	INPUT_TYPE(T_AREA, textarea_str),
 	INPUT_TYPE(T_RADIO, radio_type_str),
 	INPUT_TYPE(T_CHECKBOX, checkbox_type_str),
-	INPUT_TYPE(T_SELECT, select_str)
-//	INPUT_TYPE(T_OPTION, option_str)
+	INPUT_TYPE(T_SELECT, select_str),
+	INPUT_TYPE(T_NUMBER, number_str),
+	INPUT_TYPE(T_DATE, date_str),
+	INPUT_TYPE(T_DTIME, datetime_str),
+	INPUT_TYPE(T_DTIME_LOCAL, datetime_local_str),
+	INPUT_TYPE(T_TIME, time_str),
+	INPUT_TYPE(T_WEEK, week_str),
+	INPUT_TYPE(T_MONTH, month_str)
 };
 
 struct NAME_VALUE {
@@ -138,6 +153,17 @@ struct NAME_VALUE {
 	NAME_VALUE(int ID, string S1, string S2) {id = ID; name = S1; value = S2;}
 };
 
+// customform fields
+
+string custombuffer;
+string def_custom_filename = "";
+string base_custom_filename = "";
+string def_custom_TemplateName = "";
+
+string custom_title = ":TITLE:";
+string custom_msg = ":mg:";
+string custom_field;
+
 std::vector<NAME_VALUE> name_values;
 
 string html_form;
@@ -197,11 +223,20 @@ int convert_case(string &s)
 	mystring.ureplace("=\"RADIO\"");
 	mystring.ureplace("=\"CHECKBOX\"");
 	mystring.ureplace("=\"PASSWORD\"");
+
+	mystring.ureplace("=\"NUMBER\"");
+	mystring.ureplace("=\"DATE\"");
+	mystring.ureplace("=\"DATETIME\"");
+	mystring.ureplace("=\"DATETIME-LOCAL\"");
+	mystring.ureplace("=\"TIME\"");
+	mystring.ureplace("=\"WEEK\"");
+	mystring.ureplace("=\"MONTH\"");
+
 	mystring.ureplace("SELECTED");
 	mystring.ureplace("CHECKED");
 	mystring.ureplace("<SELECT");
 	mystring.ureplace("</SELECT");
-	mystring.ureplace("<OPTION");
+//	mystring.ureplace("<OPTION");
 	s.assign(mystring);
 	return 0;
 }
@@ -260,7 +295,9 @@ void extract_fields()
 			field_name = html_form.substr(pname, p1 - pname);
 
 			switch (input_types[i].id) {
-				case T_TEXT: case T_PASSWORD:
+				case T_TEXT: case T_PASSWORD: case T_NUMBER:
+				case T_DATE: case T_DTIME: case T_DTIME_LOCAL:
+				case T_TIME: case T_WEEK:  case T_MONTH:
 					pvalue = html_form.find(value_str, pstart);
 					if (pvalue == string::npos || pvalue > pend) break;
 					pvalue += value_str.length();
@@ -357,6 +394,7 @@ void extract_fields()
 				default:
 					break;
 			}
+
 			edit_txt.append(field_name).append(",");
 			edit_txt.append(field_value).append("\n");
 			name_values.push_back(NAME_VALUE(input_types[i].id, field_name, field_value));
@@ -375,10 +413,6 @@ void refresh_txt_custom_msg(void *)
 // called by web server thread
 void get_html_vars(struct mg_connection *conn)
 {
-static char buff[5000];
-
-	memset(buff, 0, sizeof(buff));
-
 	size_t p;
 	if (custom_select < 0) return;
 
@@ -397,8 +431,13 @@ static char buff[5000];
 			if ((p = field.find(".")) != string::npos)
 				field.erase(p);
 		}
+
+		int fld_len = mg_get_var_len(conn, field.c_str());
+		char buff[fld_len + 1];
 		memset(buff, 0, sizeof(buff));
+
 		mg_get_var(conn, field.c_str(), buff, sizeof(buff));
+
 		switch (name_values[n].id) {
 			case T_RADIO :
 				p = name_values[n].name.find(".");
@@ -421,8 +460,8 @@ static char buff[5000];
 				name_values[n].value = val;
 				line.assign(name_values[n].name).append(",").append(val);
 				break;
-			case T_SELECT:
-			default :  // T_TEXT, T_PASSWORD, T_SELECT
+			// T_TEXT, T_PASSWORD, T_SELECT, T_DATE, T_DATETIME ...
+  			default :
 				name_values[n].value = buff;
 				line.assign(name_values[n].name)
 					.append(",")
@@ -442,7 +481,9 @@ void assign_values(string &html)
 
 	for (size_t n = 0; n < name_values.size(); n++) {
 		switch (name_values[n].id) {
-			case T_TEXT : case T_PASSWORD :
+			case T_TEXT : case T_PASSWORD : case T_NUMBER :
+			case T_DATE : case T_DTIME : case T_DTIME_LOCAL :
+			case T_TIME : case T_WEEK :  case T_MONTH :
 				nm.assign("NAME=\"").append(name_values[n].name).append("\"");
 				pnm = html.find(nm);
 				if (pnm != string::npos) {
@@ -548,7 +589,6 @@ void custom_editor(struct mg_connection *conn)
 {
 	string html_edit = html_form;
 	size_t p = html_edit.find("<FORM>");
-
 	if (p == string::npos) return;
 
 	html_edit.replace(p, 6, action_str);
@@ -565,14 +605,31 @@ void custom_viewer(struct mg_connection *conn)
 	assign_values(html_view);
 
 // add readonly attribute to all input controls
-	size_t pstart, ptext, pradio, pcheckbox, ppassword, pend;
-	pstart = html_view.find("<INPUT");
+	size_t pstart, ptext, pradio, pcheckbox, ppassword, pnumber,
+		   pdate, pdtime, pdtime_local, pweek, pmonth,
+		   pend;
 
+	pstart = html_view.find("<INPUT");
 	while (pstart != string::npos) {
 		pend = html_view.find(">", pstart);
-		ppassword = html_view.find("\"PASSWORD\"", pstart);
+		ptext = html_view.find(text_type_str, pstart);
+		ppassword = html_view.find(password_type_str, pstart);
+		pnumber = html_view.find(number_str, pstart);
+		pradio = html_view.find(radio_type_str, pstart );
+		pcheckbox = html_view.find(checkbox_type_str, pstart);
+		pdate = html_view.find(date_str, pstart);
+		pdtime = html_view.find(datetime_str, pstart);
+		pdtime_local = html_view.find(datetime_local_str, pstart);
+		pweek = html_view.find(week_str, pstart);
+		pmonth = html_view.find(month_str, pstart);
+
 		if (ppassword < pend) {
 			size_t pvalue = html_view.find("VALUE=\"", pstart);
+//std::cout << "pstart " << pstart << "\n";
+//std::cout << "ppassword " << ppassword << "\n";
+//std::cout << "pend " << pend << "\n";
+//std::cout << "pvalue " << pvalue << "\n";
+//std::cout << html_view.substr(pstart, pend-pstart+1) << "\n";
 			if (pvalue < pend) {
 				pvalue += 7;
 				while (html_view[pvalue] != '\"') {
@@ -580,73 +637,55 @@ void custom_viewer(struct mg_connection *conn)
 					pvalue++;
 				}
 			}
-			html_view.replace(ppassword, 10, "\"TEXT\"");
-		}
+			html_view.replace(ppassword, password_type_str.length(), text_type_str);
+			html_view.insert(pstart + 6, " READONLY");
+		} else if (ptext < pend || pnumber < pend ||
+				  pdate < pend || pdtime < pend || pdtime_local < pend ||
+				  pweek < pend || pmonth < pend)
+			html_view.insert(pstart + 6, " READONLY");
+		else if (pradio < pend || pcheckbox < pend)
+			html_view.insert(pstart + 6, " DISABLED");
 		pstart = html_view.find("<INPUT", pend + 1);
 	}
 
-	pstart = html_view.find("<INPUT");
-	while (pstart != string::npos) {
-		pend = html_view.find(">", pstart);
-		ptext = html_view.find("\"TEXT\"", pstart);
-		pradio = html_view.find("\"RADIO\"", pstart);
-		pcheckbox = html_view.find("\"CHECKBOX\"", pstart);
-		if (ptext < pend)
-			html_view.insert(pstart + 6, " READONLY ");
-		else if (pradio < pend || pcheckbox < pend)
-			html_view.insert(pstart + 6, " DISABLED ");
-		pstart = html_view.find("<INPUT", pend + 1);
-	}
-
-	while (pstart != string::npos) {
-		pend = html_view.find(">", pstart);
-		ptext = html_view.find("\"TEXT\"", pstart);
-		ppassword = html_view.find("\"PASSWORD\"", pstart);
-		pradio = html_view.find("\"RADIO\"", pstart);
-		pcheckbox = html_view.find("\"CHECKBOX\"", pstart);
-		if (ppassword < pend) {
-			size_t pvalue = html_view.find("VALUE=\"");
-			if (pvalue < pend) {
-				pvalue += 7;
-				while (html_view[pvalue] != '\"') {
-					html_view[pvalue] = '*';
-					pvalue++;
-				}
-			}
-			html_view.replace(ppassword, 10, "\"TEXT\"");
-			html_view.insert(pstart + 6, " READONLY ");
-		} else if (ptext < pend)
-			html_view.insert(pstart + 6, " READONLY ");
-		else if (pradio < pend || pcheckbox < pend)
-			html_view.insert(pstart + 6, " DISABLED ");
-		pstart = html_view.find("<INPUT", pend + 1);
-	}
 	pstart = html_view.find("<TEXTAREA");
 	while (pstart != string::npos) {
 		pend = html_view.find(">", pstart);
-		html_view.insert(pstart + 10, " READONLY ");
+		html_view.insert(pstart + 9, " READONLY");
 		pstart = html_view.find("<TEXTAREA", pend + 1);
 	}
+
 	pstart = html_view.find("<SELECT");
 	while (pstart != string::npos) {
 		pend = html_view.find(">", pstart);
-		html_view.insert(pstart + 7, " DISABLED ");
+		html_view.insert(pstart + 7, " DISABLED");
 		pstart = html_view.find("<SELECT", pend + 1);
 	}
+
+	string fname = "";
+	size_t plc = custom_field.find(",");
+	size_t plf = custom_field.find("\n");
+	if ((plc != string::npos) && (plf != string::npos) && (plc < plf))
+		fname.append(custom_field.substr(plc+1, plf - plc - 1));
+	else
+		fname.append("RX_doc.html");
+	plc = fname.find(".");
+	if (plc != string::npos) fname.erase(plc);
+	fname.append(".htm");
+	fname.insert(0, FLMSG_temp_dir);
+
+	FILE *tempfile = fopen(fname.c_str(), "w");
+	fprintf(tempfile,"%s", html_view.c_str());
+	fclose(tempfile);
+
+	if (conn == (struct mg_connection *)0) {
+		open_url(fname.c_str());
+		return;
+	}
+
 	mg_send_data(conn, html_view.c_str(), html_view.length());
 }
 
-// customform fields
-
-string custombuffer;
-string def_custom_filename = "";
-string base_custom_filename = "";
-string def_custom_TemplateName = "";
-
-string custom_title = ":TITLE:";
-string custom_msg = ":mg:";
-string custom_field;
-
 bool using_custom_template = false;
 
 void clear_customfields()
@@ -676,10 +715,20 @@ void text_to_pairs()
 {
 	string val;
 	size_t p, p1;
+	int offset;
 	for (size_t n = 0; n < name_values.size(); n++) {
-		p = edit_txt.find(name_values[n].name);
+// look for LF+Field+COMMA
+		p = edit_txt.find("\n" + name_values[n].name + ",");
+		offset = 2; //Skip 2 characters (LF and COMMA)
+// Not found, check if it is first field in the data string (not preceeded by LF).
+		if (p == string::npos) {
+			if (edit_txt.find(name_values[n].name + ",") == 0) {
+				p = 0;
+				offset = 1; //Skip 1 character (COMMA)
+			}
+		}
 		if (p != string::npos) {
-			p += name_values[n].name.length() + 1;
+			p += name_values[n].name.length() + offset;
 			p1 = edit_txt.find("\n", p);
 			val = edit_txt.substr(p, p1 - p);
 			if (!val.empty() &&
@@ -687,7 +736,10 @@ void text_to_pairs()
 				escape(val);
 			name_values[n].value = val;
 		}
-//printf("name %s, value %s\n", name_values[n].name.c_str(), name_values[n].value.c_str());
+std::cout << 
+	"name " << name_values[n].name << 
+	", value " << name_values[n].value << 
+	"\n";
 	}
 }
 
@@ -763,6 +815,10 @@ void read_custombuffer(string data)
 			}
 		}
 	}
+	if (custom_select == -1) {
+		fl_alert2("Custom form %s not found!", fname.c_str());
+		return;
+	}
 	update_customform();
 }
 
@@ -1139,9 +1195,8 @@ void custom_set_fname(const char *fn)
 	show_filename(def_custom_filename);
 }
 
-void cb_custom_html()
+void cb_custom_html(bool exit_after_print)
 {
-	return;
 	if (custom_field.find("CUSTOM_FORM") == 0) {
 		size_t plf = custom_field.find("\n");
 		if (plf != string::npos) {
@@ -1154,6 +1209,12 @@ void cb_custom_html()
 			while ((c = fgetc(html_file)) != EOF) html_form += c;
 			fclose(html_file);
 
+			convert_case(html_form);
+			if (exit_after_print) {
+				custom_viewer((struct mg_connection *)0);
+				return;
+			}
+
 			handle_type = HANDLE_VIEW;
 			string url = "http://127.0.0.1:";
 			url.append(sz_srvr_portnbr);
