@@ -454,7 +454,7 @@ char *szTime(int typ)
 	return szDt;
 }
 
-char *szDate()
+char *szDate(int df)
 {
 	static char szDt[80];
 	time_t tmptr;
@@ -465,7 +465,7 @@ char *szDate()
 	} else {
 		localtime_r(&tmptr, &sTime);
 	}
-	switch (progStatus.dtformat) {
+	switch (df > -1 ? df: progStatus.dtformat) {
 		case 0: strftime(szDt, 79, "%Y-%m-%d", &sTime); break;
 		case 1: strftime(szDt, 79, "%m/%d/%y", &sTime); break;
 		case 2: strftime(szDt, 79, "%d/%m/%y", &sTime); break;
@@ -1487,7 +1487,7 @@ void cb_html()
 		case REDX5739B: cb_redx_5739B_html(); break;
 		case BLANK: cb_blank_html(); break;
 		case CSV: cb_csv_html(); break;
-		case CUSTOM: cb_custom_html(); break;
+		case CUSTOM: cb_custom_html(false); break;
 		default: return;
 	}
 }
@@ -1583,7 +1583,7 @@ void cb_About()
 
 void cb_folders()
 {
-	open_url(FLMSG_dir.c_str());
+	open_url(FLMSG_dir.c_str(), 1);
 }
 
 void show_filename(string p)
@@ -1747,7 +1747,6 @@ int default_handler(int event)
 // registered file drop call back to operating system
 void open_callback(const char *param)
 {
-LOG_INFO("OS file drop callback %s", param);
 	string pathname = param;
 	if (pathname.find(WRAP_EXT) != string::npos)
 		wrap_import(pathname.c_str());
@@ -1990,20 +1989,22 @@ int main(int argc, char *argv[])
 		size_t p;
 		string appdir;
 		char dirbuf[FL_PATH_MAX + 1];
-		fl_filename_expand(dirbuf, FL_PATH_MAX, argv[0]);
-		appdir.assign(dirbuf);
 
 #ifdef __WOE32__
+		fl_filename_expand(dirbuf, FL_PATH_MAX, argv[0]);
+		appdir.assign(dirbuf);
 		p = appdir.rfind("flmsg.exe");
-		appdir.erase(p);
+		if (p != string::npos)
+			appdir.erase(p);
 		p = appdir.find("FL_APPS/");
 		if (p != string::npos) {
 			FLMSG_dir.assign(appdir.substr(0, p + 8));
-		} else {
+			FLMSG_dir.append("NBEMS.files/");
+		} else if (FLMSG_dir.empty()) {
 			fl_filename_expand(dirbuf, FL_PATH_MAX, "$USERPROFILE/");
 			FLMSG_dir.assign(dirbuf);
+			FLMSG_dir.append("NBEMS.files/");
 		}
-		FLMSG_dir.append("NBEMS.files/");
 #else
 		fl_filename_absolute(dirbuf, FL_PATH_MAX, argv[0]);
 		appdir.assign(dirbuf);
@@ -2011,16 +2012,18 @@ int main(int argc, char *argv[])
 		if (p != string::npos)
 			appdir.erase(p);
 		p = appdir.find("FL_APPS/");
-		if (p != string::npos)
+		if (p != string::npos) {
 			FLMSG_dir.assign(appdir.substr(0, p + 8));
-		else {
+			FLMSG_dir.append("NBEMS.files/");
+		} else if (FLMSG_dir.empty()) {
 			fl_filename_expand(dirbuf, FL_PATH_MAX, "$HOME/");
 			FLMSG_dir = dirbuf;
+			FLMSG_dir.append(".nbems/");
 		}
-
+/*
 		DIR *isdir = 0;
 		string test_dir;
-		test_dir.assign(FLMSG_dir).append("NBEMS.files/");
+		test_dir.assign(FLMSG_dir);
 		isdir = opendir(test_dir.c_str());
 		if (isdir) {
 			FLMSG_dir = test_dir;
@@ -2028,6 +2031,7 @@ int main(int argc, char *argv[])
 		} else {
 			FLMSG_dir.append(".nbems/");
 		}
+*/
 #endif
 	}
 
@@ -2100,7 +2104,7 @@ int main(int argc, char *argv[])
 		fl_open_display();
 #endif
 		print_and_exit();
-		if (exit_after_print && selected_form != CUSTOM)
+		if (exit_after_print)
 			return 0;
 	}
 
@@ -2219,7 +2223,7 @@ void print_and_exit()
 			break;
 		case CUSTOM :
 			cb_custom_save();
-			cb_custom_html();
+			cb_custom_html(true);
 			break;
 		case MARSDAILY :
 			cb_mars_daily_save();
@@ -2626,22 +2630,35 @@ int parse_args(int argc, char **argv, int& idx)
 	return 1;
 }
 
-void open_url(const char* url)
+void open_url(const char* url, int folder)
 {
-LOG_INFO("%s", url);
+//LOG_INFO("%s", url);
 #ifndef __WOE32__
-	const char* browsers[] = {
+
+	const char *folders[] = {
 #  ifdef __APPLE__
-		getenv("FLDIGI_BROWSER"), // valid for any OS - set by user
 		"open"                    // OS X
 #  else
 		"fl-xdg-open",            // Puppy Linux
-		"xdg-open",               // other Unix-Linux distros
-		getenv("FLDIGI_BROWSER"), // force use of spec'd browser
+		"xdg-open"                // all other Linux/Unix
+#endif
+	};
+
+	const char* browsers[] = {
+#  ifdef __APPLE__
+		getenv("FLMSG_BROWSER"),  // valid for any OS - set by user
+		getenv("BROWSER"),        // valid for any OS - set by user
+		"open"                    // OS X
+#  else
+		"fl-xdg-open",            // Puppy Linux
+		getenv("FLMSG_BROWSER"),  // force use of spec'd browser
 		getenv("BROWSER"),        // most Linux distributions
-		"sensible-browser",
-		"firefox",
-		"mozilla"                 // must be something out there!
+		"chromium-browser",       // preferred browser for HTML-5
+		"firefox",                // nice, but incomplete HTML-5
+		"mozilla",                // nice, but incomplete HTML-5
+		"xdg-open",               // let OS determine browser
+		"sensible-browser"        // must be something out there!
+
 #  endif
 	};
 	switch (fork()) {
@@ -2650,10 +2667,20 @@ LOG_INFO("%s", url);
 		unsetenv("MALLOC_CHECK_");
 		unsetenv("MALLOC_PERTURB_");
 #  endif
-		for (size_t i = 0; i < sizeof(browsers)/sizeof(browsers[0]); i++)
-			if (browsers[i])
-				execlp(browsers[i], browsers[i], url, (char*)0);
+
+		if (folder) {
+			for (size_t i = 0; i < sizeof(folders)/sizeof(folders[0]); i++) {
+				if (folders[i])
+					execlp(folders[i], folders[i], url, (char*)0);
+			}
+		} else {
+			for (size_t i = 0; i < sizeof(browsers)/sizeof(browsers[0]); i++) {
+				if (browsers[i])
+					execlp(browsers[i], browsers[i], url, (char*)0);
+			}
+		}
 		exit(EXIT_FAILURE);
+
 	case -1:
 		fl_alert2(_("Could not run a web browser:\n%s\n\n"
 			 "Open this URL manually:\n%s"),
