@@ -1,22 +1,22 @@
-// =====================================================================
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// ics203.cxx
+// This file is part of flmsg
 //
-// Author: Dave Freese, W1HKJ
-// Copyright: 2010
+// flrig is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// flrig is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  It is
-// copyright under the GNU General Public License.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
-//
-// =====================================================================
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #include <stdlib.h>
 #include <iostream>
@@ -269,6 +269,127 @@ void clear_203fields()
 	}
 }
 
+bool check_203fields() {
+	if (s203_incident != txt_203_incident->value())
+		return true;
+	if (s203_date != txt_203_date->value())
+		return true;
+	if (s203_time != txt_203_time->value())
+		return true;
+	if (s203_op_period != txt_203_op_period->value())
+		return true;
+	if (s203_incident_commander != txt_203_incident_commander->value())
+		return true;
+	if (s203_incident_deputy != txt_203_incident_deputy->value())
+		return true;
+	if (s203_incident_safety_officer != txt_203_incident_safety_officer->value())
+		return true;
+	if (s203_incident_info_officer != txt_203_incident_info_officer->value())
+		return true;
+	if (s203_liaison_officer != txt_203_liaison_officer->value())
+		return true;
+	if (s203_prepared_by != txt_203_prepared_by->value())
+		return true;
+	if (s203_planning_chief != txt_203_planning_chief->value())
+		return true;
+	if (s203_planning_deputy != txt_203_planning_deputy->value())
+		return true;
+	if (s203_resources_unit != txt_203_resources_unit->value())
+		return true;
+	if (s203_situation_unit != txt_203_situation_unit->value())
+		return true;
+	if (s203_documentation_unit != txt_203_documentation_unit->value())
+		return true;
+	if (s203_demobilization_unit != txt_203_demobilization_unit->value())
+		return true;
+	if (s203_logistics_chief != txt_203_logistics_chief->value())
+		return true;
+	if (s203_logistics_deputy != txt_203_logistics_deputy->value())
+		return true;
+	if (s203_support_director != txt_203_support_director->value())
+		return true;
+	if (s203_supply_unit != txt_203_supply_unit->value())
+		return true;
+	if (s203_facilities_unit != txt_203_facilities_unit->value())
+		return true;
+	if (s203_ground_support != txt_203_ground_support->value())
+		return true;
+	if (s203_service_director != txt_203_service_director->value())
+		return true;
+	if (s203_communications_unit != txt_203_communications_unit->value())
+		return true;
+	if (s203_medical_unit != txt_203_medical_unit->value())
+		return true;
+	if (s203_food_unit != txt_203_food_unit->value())
+		return true;
+	if (s203_ops_chief != txt_203_ops_chief->value())
+		return true;
+	if (s203_ops_deputy != txt_203_ops_deputy->value())
+		return true;
+	if (s203_b1_director != txt_203_b1_director->value())
+		return true;
+	if (s203_b1_deputy != txt_203_b1_deputy->value())
+		return true;
+	if (s203_b2_director != txt_203_b2_director->value())
+		return true;
+	if (s203_b2_deputy != txt_203_b2_deputy->value())
+		return true;
+	if (s203_b3_director != txt_203_b3_director->value())
+		return true;
+	if (s203_b3_deputy != txt_203_b3_deputy->value())
+		return true;
+	if (s203_air_ops_br_dir != txt_203_air_ops_br_dir->value())
+		return true;
+	if (s203_air_tactical_group_sup != txt_203_air_tactical_group_sup->value())
+		return true;
+	if (s203_air_support_group_sup != txt_203_air_support_group_sup->value())
+		return true;
+	if (s203_helicopter_coordinator != txt_203_helicopter_coordinator->value())
+		return true;
+	if (s203_air_tanker_fixed_wing != txt_203_air_tanker_fixed_wing->value())
+		return true;
+	if (s203_finance_chief != txt_203_finance_chief->value())
+		return true;
+	if (s203_finance_deputy != txt_203_finance_deputy->value())
+		return true;
+	if (s203_time_unit != txt_203_time_unit->value())
+		return true;
+	if (s203_procurement_unit != txt_203_procurement_unit->value())
+		return true;
+	if (s203_claims_unit != txt_203_claims_unit->value())
+		return true;
+	if (s203_cost_unit != txt_203_cost_unit->value())
+		return true;
+
+	for (int i = 0; i < 7; i++) {
+		if (s203_agency[i] != txt_203_agency[i]->value())
+			return true;
+		if (s203_agency_name[i] != txt_203_agency_name[i]->value())
+			return true;
+	}
+
+	for (int i = 0; i < 3; i++) {
+		if (s203_tech_spc[i] != txt_203_tech_spc[i]->value())
+			return true;
+	}
+
+	for (int i = 0; i < 5; i++) {
+		if (s203_b1_div[i] != txt_203_b1_div[i]->value())
+			return true;
+		if (s203_b1_grp[i] != txt_203_b1_grp[i]->value())
+			return true;
+		if (s203_b2_div[i] != txt_203_b2_div[i]->value())
+			return true;
+		if (s203_b2_grp[i] != txt_203_b2_grp[i]->value())
+			return true;
+		if (s203_b3_div[i] != txt_203_b3_div[i]->value())
+			return true;
+		if (s203_b3_grp[i] != txt_203_b3_grp[i]->value())
+			return true;
+	}
+	return false;
+}
+
 void update_203fields()
 {
 	s203_incident = txt_203_incident->value();
@@ -321,9 +442,11 @@ void update_203fields()
 		s203_agency[i] = txt_203_agency[i]->value();
 		s203_agency_name[i] = txt_203_agency_name[i]->value();
 	}
+
 	for (int i = 0; i < 3; i++) {
 		s203_tech_spc[i] = txt_203_tech_spc[i]->value();
 	}
+
 	for (int i = 0; i < 5; i++) {
 		s203_b1_div[i] = txt_203_b1_div[i]->value();
 		s203_b1_grp[i] = txt_203_b1_grp[i]->value();
@@ -476,71 +599,73 @@ string &ics_n(string & subst, int n)
 	return subst;
 }
 
-void make_buff203()
+void make_buff203(bool compress = false)
 {
-	update_203fields();
-
-	buff203.append( lineout( ics203_incident, s203_incident ) );
-	buff203.append( lineout( ics203_date, s203_date ) );
-	buff203.append( lineout( ics203_time, s203_time ) );
-	buff203.append( lineout( ics203_op_period, s203_op_period ) );
-	buff203.append( lineout( ics203_incident_commander, s203_incident_commander ) );
-	buff203.append( lineout( ics203_incident_deputy, s203_incident_deputy ) );
-	buff203.append( lineout( ics203_incident_safety_officer, s203_incident_safety_officer ) );
-	buff203.append( lineout( ics203_incident_info_officer, s203_incident_info_officer ) );
-	buff203.append( lineout( ics203_liaison_officer, s203_liaison_officer ) );
-	buff203.append( lineout( ics203_prepared_by, s203_prepared_by ) );
-	buff203.append( lineout( ics203_planning_chief, s203_planning_chief ) );
-	buff203.append( lineout( ics203_planning_deputy, s203_planning_deputy ) );
-	buff203.append( lineout( ics203_resources_unit, s203_resources_unit ) );
-	buff203.append( lineout( ics203_situation_unit, s203_situation_unit ) );
-	buff203.append( lineout( ics203_documentation_unit, s203_documentation_unit ) );
-	buff203.append( lineout( ics203_demobilization_unit, s203_demobilization_unit ) );
-	buff203.append( lineout( ics203_logistics_chief, s203_logistics_chief ) );
-	buff203.append( lineout( ics203_logistics_deputy, s203_logistics_deputy ) );
-	buff203.append( lineout( ics203_support_director, s203_support_director ) );
-	buff203.append( lineout( ics203_supply_unit, s203_supply_unit ) );
-	buff203.append( lineout( ics203_facilities_unit, s203_facilities_unit ) );
-	buff203.append( lineout( ics203_ground_support, s203_ground_support ) );
-	buff203.append( lineout( ics203_service_director, s203_service_director ) );
-	buff203.append( lineout( ics203_communications_unit, s203_communications_unit ) );
-	buff203.append( lineout( ics203_medical_unit, s203_medical_unit ) );
-	buff203.append( lineout( ics203_food_unit, s203_food_unit ) );
-	buff203.append( lineout( ics203_ops_chief, s203_ops_chief ) );
-	buff203.append( lineout( ics203_ops_deputy, s203_ops_deputy ) );
-	buff203.append( lineout( ics203_b1_director, s203_b1_director ) );
-	buff203.append( lineout( ics203_b1_deputy, s203_b1_deputy ) );
-	buff203.append( lineout( ics203_b2_director, s203_b2_director ) );
-	buff203.append( lineout( ics203_b2_deputy, s203_b2_deputy ) );
-	buff203.append( lineout( ics203_b3_director, s203_b3_director ) );
-	buff203.append( lineout( ics203_b3_deputy, s203_b3_deputy ) );
-	buff203.append( lineout( ics203_air_ops_br_dir, s203_air_ops_br_dir ) );
-	buff203.append( lineout( ics203_air_tactical_group_sup, s203_air_tactical_group_sup ) );
-	buff203.append( lineout( ics203_air_support_group_sup, s203_air_support_group_sup ) );
-	buff203.append( lineout( ics203_helicopter_coordinator, s203_helicopter_coordinator ) );
-	buff203.append( lineout( ics203_air_tanker_fixed_wing, s203_air_tanker_fixed_wing ) );
-	buff203.append( lineout( ics203_finance_chief, s203_finance_chief ) );
-	buff203.append( lineout( ics203_finance_deputy, s203_finance_deputy ) );
-	buff203.append( lineout( ics203_time_unit, s203_time_unit ) );
-	buff203.append( lineout( ics203_procurement_unit, s203_procurement_unit ) );
-	buff203.append( lineout( ics203_claims_unit, s203_claims_unit ) );
-	buff203.append( lineout( ics203_cost_unit, s203_cost_unit ) );
+	string mbuff;
+	mbuff.clear();
+	mbuff.append( lineout( ics203_incident, s203_incident ) );
+	mbuff.append( lineout( ics203_date, s203_date ) );
+	mbuff.append( lineout( ics203_time, s203_time ) );
+	mbuff.append( lineout( ics203_op_period, s203_op_period ) );
+	mbuff.append( lineout( ics203_incident_commander, s203_incident_commander ) );
+	mbuff.append( lineout( ics203_incident_deputy, s203_incident_deputy ) );
+	mbuff.append( lineout( ics203_incident_safety_officer, s203_incident_safety_officer ) );
+	mbuff.append( lineout( ics203_incident_info_officer, s203_incident_info_officer ) );
+	mbuff.append( lineout( ics203_liaison_officer, s203_liaison_officer ) );
+	mbuff.append( lineout( ics203_prepared_by, s203_prepared_by ) );
+	mbuff.append( lineout( ics203_planning_chief, s203_planning_chief ) );
+	mbuff.append( lineout( ics203_planning_deputy, s203_planning_deputy ) );
+	mbuff.append( lineout( ics203_resources_unit, s203_resources_unit ) );
+	mbuff.append( lineout( ics203_situation_unit, s203_situation_unit ) );
+	mbuff.append( lineout( ics203_documentation_unit, s203_documentation_unit ) );
+	mbuff.append( lineout( ics203_demobilization_unit, s203_demobilization_unit ) );
+	mbuff.append( lineout( ics203_logistics_chief, s203_logistics_chief ) );
+	mbuff.append( lineout( ics203_logistics_deputy, s203_logistics_deputy ) );
+	mbuff.append( lineout( ics203_support_director, s203_support_director ) );
+	mbuff.append( lineout( ics203_supply_unit, s203_supply_unit ) );
+	mbuff.append( lineout( ics203_facilities_unit, s203_facilities_unit ) );
+	mbuff.append( lineout( ics203_ground_support, s203_ground_support ) );
+	mbuff.append( lineout( ics203_service_director, s203_service_director ) );
+	mbuff.append( lineout( ics203_communications_unit, s203_communications_unit ) );
+	mbuff.append( lineout( ics203_medical_unit, s203_medical_unit ) );
+	mbuff.append( lineout( ics203_food_unit, s203_food_unit ) );
+	mbuff.append( lineout( ics203_ops_chief, s203_ops_chief ) );
+	mbuff.append( lineout( ics203_ops_deputy, s203_ops_deputy ) );
+	mbuff.append( lineout( ics203_b1_director, s203_b1_director ) );
+	mbuff.append( lineout( ics203_b1_deputy, s203_b1_deputy ) );
+	mbuff.append( lineout( ics203_b2_director, s203_b2_director ) );
+	mbuff.append( lineout( ics203_b2_deputy, s203_b2_deputy ) );
+	mbuff.append( lineout( ics203_b3_director, s203_b3_director ) );
+	mbuff.append( lineout( ics203_b3_deputy, s203_b3_deputy ) );
+	mbuff.append( lineout( ics203_air_ops_br_dir, s203_air_ops_br_dir ) );
+	mbuff.append( lineout( ics203_air_tactical_group_sup, s203_air_tactical_group_sup ) );
+	mbuff.append( lineout( ics203_air_support_group_sup, s203_air_support_group_sup ) );
+	mbuff.append( lineout( ics203_helicopter_coordinator, s203_helicopter_coordinator ) );
+	mbuff.append( lineout( ics203_air_tanker_fixed_wing, s203_air_tanker_fixed_wing ) );
+	mbuff.append( lineout( ics203_finance_chief, s203_finance_chief ) );
+	mbuff.append( lineout( ics203_finance_deputy, s203_finance_deputy ) );
+	mbuff.append( lineout( ics203_time_unit, s203_time_unit ) );
+	mbuff.append( lineout( ics203_procurement_unit, s203_procurement_unit ) );
+	mbuff.append( lineout( ics203_claims_unit, s203_claims_unit ) );
+	mbuff.append( lineout( ics203_cost_unit, s203_cost_unit ) );
 
 	for (int i = 0; i < 7; i++) {
-		buff203.append( lineout( ics_n( ics203_agency, i ), s203_agency[i] ) );
-		buff203.append( lineout( ics_n( ics203_agency_name, i ), s203_agency_name[i] ) );
+		mbuff.append( lineout( ics_n( ics203_agency, i ), s203_agency[i] ) );
+		mbuff.append( lineout( ics_n( ics203_agency_name, i ), s203_agency_name[i] ) );
 	}
 	for (int i = 0; i < 3; i++) {
-		buff203.append( lineout( ics_n( ics203_tech_spc, i ), s203_tech_spc[i] ) );
+		mbuff.append( lineout( ics_n( ics203_tech_spc, i ), s203_tech_spc[i] ) );
 	}
 	for (int i = 0; i < 5; i++) {
-		buff203.append( lineout( ics_n( ics203_b1_div, i ), s203_b1_div[i] ) );
-		buff203.append( lineout( ics_n( ics203_b1_grp, i ), s203_b1_grp[i] ) );
-		buff203.append( lineout( ics_n( ics203_b2_div, i ), s203_b2_div[i] ) );
-		buff203.append( lineout( ics_n( ics203_b2_grp, i ), s203_b2_grp[i] ) );
-		buff203.append( lineout( ics_n( ics203_b3_div, i ), s203_b3_div[i] ) );
-		buff203.append( lineout( ics_n( ics203_b3_grp, i ), s203_b3_grp[i] ) );
+		mbuff.append( lineout( ics_n( ics203_b1_div, i ), s203_b1_div[i] ) );
+		mbuff.append( lineout( ics_n( ics203_b1_grp, i ), s203_b1_grp[i] ) );
+		mbuff.append( lineout( ics_n( ics203_b2_div, i ), s203_b2_div[i] ) );
+		mbuff.append( lineout( ics_n( ics203_b2_grp, i ), s203_b2_grp[i] ) );
+		mbuff.append( lineout( ics_n( ics203_b3_div, i ), s203_b3_div[i] ) );
+		mbuff.append( lineout( ics_n( ics203_b3_grp, i ), s203_b3_grp[i] ) );
 	}
+	if (compress) compress_maybe(mbuff);
+	buff203.append(mbuff);
 }
 
 void read_203_buffer(string data)
@@ -614,6 +739,12 @@ void read_203_buffer(string data)
 
 void cb_203_new()
 {
+	if (check_203fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 1) {
+			update_header(CHANGED);
+			cb_203_save();
+		}
+	}
 	clear_203_form();
 	clear_header();
 	def_203_filename = ICS_msg_dir;
@@ -642,10 +773,34 @@ void cb_203_wrap_import(string wrapfilename, string inpbuffer)
 	using_ics203_template = false;
 }
 
+int eval_203_fsize()
+{
+	Ccrc16 chksum;
+	evalstr.append("[WRAP:beg][WRAP:lf][WRAP:fn ");
+	evalstr.append(base_203_filename).append("]");
+	update_203fields();
+	update_header(FROM);
+	evalstr.append(header("<ics203>"));
+	buff203.clear();
+	make_buff203(true);
+	if (buff203.empty()) return 0;
+	compress_maybe( buff203 );
+	evalstr.append( buff203 );
+	evalstr.append("[WRAP:chksum ").append(chksum.scrc16(evalstr)).append("][WRAP:end]");
+	return evalstr.length();
+}
+
 void cb_203_wrap_export()
 {
+	if (check_203fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_203fields();
+
 	if (base_203_filename == "new"F203_EXT || base_203_filename == "default"F203_EXT)
-		cb_203_save_as();
+		if (!cb_203_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
 	wrapfilename.append(base_203_filename);
@@ -657,26 +812,37 @@ void cb_203_wrap_export()
 	if (p) {
 		string pext = fl_filename_ext(p);
 		wrapfilename = p;
-		update_header(true);
-		buff203.assign(header("<ics203>", true, true));
-		make_buff203();
+		update_header(FROM);
+		buff203.assign(header("<ics203>"));
+		make_buff203(true);
 		export_wrapfile(base_203_filename, wrapfilename, buff203, pext != ".wrap");
+
+		buff203.assign(header("<ics203>"));
+		make_buff203(true);
+		write_203(def_203_filename);
 	}
 }
 
 void cb_203_wrap_autosend()
 {
-	if (base_203_filename == "new"F203_EXT || 
-		base_203_filename == "default"F203_EXT ||
-		using_ics203_template == true)
-		cb_203_save_as();
+	if (check_203fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_203fields();
 
-	string wrapfilename = WRAP_auto_dir;
-	wrapfilename.append("wrap_auto_file");
-	update_header(true);
-	buff203.assign(header("<ics203>", true, true));
-	make_buff203();
-	export_wrapfile(base_203_filename, wrapfilename, buff203, false);
+	if (base_203_filename == "new"F203_EXT || base_203_filename == "default"F203_EXT)
+		if (!cb_203_save_as()) return;
+
+	update_header(FROM);
+	buff203.assign(header("<ics203>"));
+	make_buff203(true);
+	xfr_via_socket(base_203_filename, buff203);
+
+	buff203.assign(header("<ics203>"));
+	make_buff203(true);
+	write_203(def_203_filename);
 }
 
 void cb_203_load_template()
@@ -707,7 +873,9 @@ void cb_203_save_template()
 			"Template file\t*"T203_EXT,
 			def_203_filename.c_str());
 	if (p) {
-		clear_header();
+		update_header(CHANGED);
+		buff203.assign(header("<ics203>"));
+		make_buff203();
 		write_203(p);
 	}
 }
@@ -725,6 +893,9 @@ void cb_203_save_as_template()
 		if (strlen(pext) == 0) def_203_TemplateName.append(T203_EXT);
 		remove_spaces_from_filename(def_203_TemplateName);
 		clear_header();
+		update_header(CHANGED);
+		buff203.assign(header("<ics203>"));
+		make_buff203();
 		write_203(def_203_TemplateName);
 		show_filename(def_203_TemplateName);
 		using_ics203_template = true;
@@ -748,14 +919,12 @@ void write_203(string s)
 {
 	FILE *file203 = fopen(s.c_str(), "w");
 	if (!file203) return;
-	update_header();
-	buff203.assign(save_header("<ics203>"));
-	make_buff203();
+
 	fwrite(buff203.c_str(), buff203.length(), 1, file203);
 	fclose(file203);
 }
 
-void cb_203_save_as()
+bool cb_203_save_as()
 {
 	const char *p;
 	string newfilename;
@@ -770,8 +939,10 @@ void cb_203_save_as()
 
 	p = FSEL::saveas(_("Save data file"), "ICS-203\t*"F203_EXT,
 					newfilename.c_str());
-	if (!p) return;
-	if (strlen(p) == 0) return;
+
+	if (!p) return false;
+	if (strlen(p) == 0) return false;
+
 	if (progStatus.sernbr_fname) {
 		string haystack = p;
 		if (haystack.find(newfilename) != string::npos) {
@@ -790,11 +961,15 @@ void cb_203_save_as()
 	if (strlen(pext) == 0) def_203_filename.append(F203_EXT);
 
 	remove_spaces_from_filename(def_203_filename);
-	clear_header();
+	update_203fields();
+	update_header(NEW);
+	buff203.assign(header("<ics203>"));
+	make_buff203();
 	write_203(def_203_filename);
 
 	using_ics203_template = false;
 	show_filename(def_203_filename);
+	return true;
 }
 
 void cb_203_save()
@@ -805,6 +980,10 @@ void cb_203_save()
 		cb_203_save_as();
 		return;
 	}
+	if (check_203fields()) update_header(CHANGED);
+	update_203fields();
+	buff203.assign(header("<ics203>"));
+	make_buff203();
 	write_203(def_203_filename);
 	using_ics203_template = false;
 }
