@@ -1,22 +1,22 @@
-// =====================================================================
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// ics206.cxx
+// This file is part of flmsg
 //
-// Author: Dave Freese, W1HKJ
-// Copyright: 2010
+// flrig is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// flrig is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  It is
-// copyright under the GNU General Public License.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
-//
-// =====================================================================
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #include <stdlib.h>
 #include <iostream>
@@ -200,6 +200,62 @@ void clear_206fields()
 	}
 }
 
+bool check_206fields()
+{
+	if (s206_name != txt_206_name->value())
+		return true;
+	if (s206_period != txt_206_op_period->value())
+		return true;
+	if (s206_date_prepared != txt_206_date_prepared->value())
+		return true;
+	if (s206_time_prepared != txt_206_time_prepared->value())
+		return true;
+	if (s206_procedure != txt_206_procedure->buffer()->text())
+		return true;
+	if (s206_preparer != txt_206_preparer->value())
+		return true;
+	if (s206_reviewer != txt_206_reviewer->value())
+		return true;
+
+	for (int i = 0; i < 5; i++) {
+		if (s206_medaid_sta[i] != txt_206_medaid_sta[i]->value())
+			return true;
+		if (s206_medaid_loc[i] != txt_206_medaid_loc[i]->value())
+			return true;
+		if (s206_transport_name[i] != txt_206_transport_name[i]->value())
+			return true;
+		if (s206_transport_address[i] != txt_206_transport_address[i]->value())
+			return true;
+		if (s206_transport_phone[i] != txt_206_transport_phone[i]->value())
+			return true;
+		if (s206_ambulance_name[i] != txt_206_ambulance_name[i]->value())
+			return true;
+		if (s206_ambulance_loc[i] != txt_206_ambulance_loc[i]->value())
+			return true;
+		if (s206_hosp_name[i] != txt_206_hosp_name[i]->value())
+			return true;
+		if (s206_hosp_address[i] != txt_206_hosp_address[i]->value())
+			return true;
+		if (s206_hosp_phone[i] != txt_206_hosp_phone[i]->value())
+			return true;
+		if (s206_hosp_airtime[i] != txt_206_hosp_airtime[i]->value())
+			return true;
+		if (s206_hosp_gndtime[i] != txt_206_hosp_gndtime[i]->value())
+			return true;
+		if (b206_medaid_paramedics[i] != btn_206_medaid_paramedics[i]->value())
+			return true;
+		if (b206_transport_paramedics[i] != btn_206_transport_paramedics[i]->value())
+			return true;
+		if (b206_ambulance_paramedics[i] != btn_206_ambulance_paramedics[i]->value())
+			return true;
+		if (b206_hosp_helipad[i] != btn_206_hosp_helipad[i]->value())
+			return true;
+		if (b206_hosp_burn_center[i] != btn_206_hosp_burn_center[i]->value())
+			return true;
+	}
+	return false;
+}
+
 void update_206fields()
 {
 	s206_name = txt_206_name->value();
@@ -223,7 +279,6 @@ void update_206fields()
 		s206_hosp_phone[i] = txt_206_hosp_phone[i]->value();
 		s206_hosp_airtime[i] = txt_206_hosp_airtime[i]->value();
 		s206_hosp_gndtime[i] = txt_206_hosp_gndtime[i]->value();
-
 		b206_medaid_paramedics[i] = btn_206_medaid_paramedics[i]->value();
 		b206_transport_paramedics[i] = btn_206_transport_paramedics[i]->value();
 		b206_ambulance_paramedics[i] = btn_206_ambulance_paramedics[i]->value();
@@ -298,20 +353,17 @@ void clear_206_form()
 	}
 }
 
-void make_buff206()
+void make_buff206(bool compress = false)
 {
-	update_206fields();
-	buff206.clear();
-
-	buff206 = header("<ics206>");
-
-	buff206.append( lineout( ics206_name, s206_name ) );
-	buff206.append( lineout( ics206_period, s206_period ) );
-	buff206.append( lineout( ics206_date_prepared, s206_date_prepared ) );
-	buff206.append( lineout( ics206_time_prepared, s206_time_prepared ) );
-	buff206.append( lineout( ics206_procedure, s206_procedure ) );
-	buff206.append( lineout( ics206_preparer, s206_preparer ) );
-	buff206.append( lineout( ics206_reviewer, s206_reviewer ) );
+	string mbuff;
+	mbuff.clear();
+	mbuff.append( lineout( ics206_name, s206_name ) );
+	mbuff.append( lineout( ics206_period, s206_period ) );
+	mbuff.append( lineout( ics206_date_prepared, s206_date_prepared ) );
+	mbuff.append( lineout( ics206_time_prepared, s206_time_prepared ) );
+	mbuff.append( lineout( ics206_procedure, s206_procedure ) );
+	mbuff.append( lineout( ics206_preparer, s206_preparer ) );
+	mbuff.append( lineout( ics206_reviewer, s206_reviewer ) );
 
 	for (int i = 0; i < 5; i++) {
 		ics206_medaid_sta[5] = ics206_medaid_loc[5] = ics206_medaid_paramedics[5] =
@@ -323,33 +375,35 @@ void make_buff206()
 		ics206_hosp_phone[6] = ics206_hosp_helipad[6] =
 		ics206_hosp_burn_center[6] = '0' + i;
 
-		buff206.append( lineout( ics206_medaid_sta, s206_medaid_sta[i] ) );
-		buff206.append( lineout( ics206_medaid_loc, s206_medaid_loc[i] ) );
-		buff206.append( binout( ics206_medaid_paramedics, b206_medaid_paramedics[i] ) );
+		mbuff.append( lineout( ics206_medaid_sta, s206_medaid_sta[i] ) );
+		mbuff.append( lineout( ics206_medaid_loc, s206_medaid_loc[i] ) );
+		mbuff.append( binout( ics206_medaid_paramedics, b206_medaid_paramedics[i] ) );
 
-		buff206.append( lineout( ics206_transport_address, s206_transport_address[i] ) );
-		buff206.append( lineout( ics206_transport_name, s206_transport_name[i] ) );
-		buff206.append( lineout( ics206_transport_phone, s206_transport_phone[i] ) );
-		buff206.append( binout( ics206_transport_paramedics, b206_transport_paramedics[i] ) );
+		mbuff.append( lineout( ics206_transport_address, s206_transport_address[i] ) );
+		mbuff.append( lineout( ics206_transport_name, s206_transport_name[i] ) );
+		mbuff.append( lineout( ics206_transport_phone, s206_transport_phone[i] ) );
+		mbuff.append( binout( ics206_transport_paramedics, b206_transport_paramedics[i] ) );
 
-		buff206.append( lineout( ics206_ambulance_loc, s206_ambulance_loc[i] ) );
-		buff206.append( lineout( ics206_ambulance_name, s206_ambulance_name[i] ) );
-		buff206.append( binout( ics206_ambulance_paramedics, b206_ambulance_paramedics[i] ) );
+		mbuff.append( lineout( ics206_ambulance_loc, s206_ambulance_loc[i] ) );
+		mbuff.append( lineout( ics206_ambulance_name, s206_ambulance_name[i] ) );
+		mbuff.append( binout( ics206_ambulance_paramedics, b206_ambulance_paramedics[i] ) );
 
-		buff206.append( lineout( ics206_hosp_name, s206_hosp_name[i] ) );
-		buff206.append( lineout( ics206_hosp_address, s206_hosp_address[i] ) );
-		buff206.append( lineout( ics206_hosp_phone, s206_hosp_phone[i] ) );
-		buff206.append( lineout( ics206_hosp_airtime, s206_hosp_airtime[i] ) );
-		buff206.append( lineout( ics206_hosp_gndtime, s206_hosp_gndtime[i] ) );
-		buff206.append( binout( ics206_hosp_helipad, b206_hosp_helipad[i] ) );
-		buff206.append( binout( ics206_hosp_burn_center, b206_hosp_burn_center[i] ) );
+		mbuff.append( lineout( ics206_hosp_name, s206_hosp_name[i] ) );
+		mbuff.append( lineout( ics206_hosp_address, s206_hosp_address[i] ) );
+		mbuff.append( lineout( ics206_hosp_phone, s206_hosp_phone[i] ) );
+		mbuff.append( lineout( ics206_hosp_airtime, s206_hosp_airtime[i] ) );
+		mbuff.append( lineout( ics206_hosp_gndtime, s206_hosp_gndtime[i] ) );
+		mbuff.append( binout( ics206_hosp_helipad, b206_hosp_helipad[i] ) );
+		mbuff.append( binout( ics206_hosp_burn_center, b206_hosp_burn_center[i] ) );
 	}
-
+	if (compress) compress_maybe(mbuff);
+	buff206.append(mbuff);
 }
 
 void read_206_buffer(string data)
 {
 	clear_206fields();
+	read_header(data);
 
 	s206_name = findstr(data, ics206_name);
 	s206_period = findstr(data, ics206_period);
@@ -436,7 +490,14 @@ void read_206_buffer(string data)
 
 void cb_206_new()
 {
+	if (check_206fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 1) {
+			update_header(CHANGED);
+			cb_206_save();
+		}
+	}
 	clear_206_form();
+	clear_header();
 	def_206_filename = ICS_msg_dir;
 	def_206_filename.append("new"F206_EXT);
 	show_filename(def_206_filename);
@@ -463,10 +524,34 @@ void cb_206_wrap_import(string wrapfilename, string inpbuffer)
 	using_ics206_template = false;
 }
 
+int eval_206_fsize()
+{
+	Ccrc16 chksum;
+	evalstr.assign("[WRAP:beg][WRAP:lf][WRAP:fn ");
+	evalstr.append(base_206_filename).append("]");
+	update_206fields();
+	update_header(FROM);
+	evalstr.append(header("<ics206>"));
+	buff206.clear();
+	make_buff206(true);
+	if (buff206.empty()) return 0;
+	compress_maybe( buff206 );
+	evalstr.append( buff206 );
+	evalstr.append("[WRAP:chksum ").append(chksum.scrc16(evalstr)).append("][WRAP:end]");
+	return evalstr.length();
+}
+
 void cb_206_wrap_export()
 {
+	if (check_206fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_206fields();
+
 	if (base_206_filename == "new"F206_EXT || base_206_filename == "default"F206_EXT)
-		cb_206_save_as();
+		if (!cb_206_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
 	wrapfilename.append(base_206_filename);
@@ -478,22 +563,37 @@ void cb_206_wrap_export()
 	if (p) {
 		string pext = fl_filename_ext(p);
 		wrapfilename = p;
-		make_buff206();
+		update_header(FROM);
+		buff206.assign(header("<ics206>"));
+		make_buff206(true);
 		export_wrapfile(base_206_filename, wrapfilename, buff206, pext != ".wrap");
+
+		buff206.assign(header("<ics206>"));
+		make_buff206(false);
+		write_206(def_206_filename);
 	}
 }
 
 void cb_206_wrap_autosend()
 {
-	if (base_206_filename == "new"F206_EXT || 
-		base_206_filename == "default"F206_EXT ||
-		using_ics206_template == true)
-		cb_206_save_as();
+	if (check_206fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_206fields();
 
-	string wrapfilename = WRAP_auto_dir;
-	wrapfilename.append("wrap_auto_file");
-	make_buff206();
-	export_wrapfile(base_206_filename, wrapfilename, buff206, false);
+	if (base_206_filename == "new"F206_EXT || base_206_filename == "default"F206_EXT)
+		if (!cb_206_save_as()) return;
+
+	update_header(FROM);
+	buff206.assign(header("<ics206>"));
+	make_buff206(true);
+	xfr_via_socket(base_206_filename, buff206);
+
+	buff206.assign(header("<ics206>"));
+	make_buff206(false);
+	write_206(def_206_filename);
 }
 
 void cb_206_load_template()
@@ -523,8 +623,12 @@ void cb_206_save_template()
 			"Save template file",
 			"Template file\t*"T206_EXT,
 			def_206_filename.c_str());
-	if (p)
+	if (p) {
+		update_header(CHANGED);
+		buff206.assign(header("<ics206>"));
+		make_buff206();
 		write_206(p);
+	}
 }
 
 void cb_206_save_as_template()
@@ -538,7 +642,11 @@ void cb_206_save_as_template()
 		const char *pext = fl_filename_ext(p);
 		def_206_TemplateName = p;
 		if (strlen(pext) == 0) def_206_TemplateName.append(T206_EXT);
-		remove_spaces_from_filename(def_206_TemplateName);
+		remove_spaces_from_filename(def_206_TemplateName);\
+		clear_header();
+		update_header(CHANGED);
+		buff206.assign(header("<ics206>"));
+		make_buff206();
 		write_206(def_206_TemplateName);
 		show_filename(def_206_TemplateName);
 		using_ics206_template = true;
@@ -562,12 +670,12 @@ void write_206(string s)
 {
 	FILE *file206 = fopen(s.c_str(), "w");
 	if (!file206) return;
-	make_buff206();
+
 	fwrite(buff206.c_str(), buff206.length(), 1, file206);
 	fclose(file206);
 }
 
-void cb_206_save_as()
+bool cb_206_save_as()
 {
 	const char *p;
 	string newfilename;
@@ -582,8 +690,10 @@ void cb_206_save_as()
 
 	p = FSEL::saveas(_("Save data file"), "ICS-206\t*"F206_EXT,
 					newfilename.c_str());
-	if (!p) return;
-	if (strlen(p) == 0) return;
+
+	if (!p) return false;
+	if (strlen(p) == 0) return false;
+
 	if (progStatus.sernbr_fname) {
 		string haystack = p;
 		if (haystack.find(newfilename) != string::npos) {
@@ -602,10 +712,15 @@ void cb_206_save_as()
 	if (strlen(pext) == 0) def_206_filename.append(F206_EXT);
 
 	remove_spaces_from_filename(def_206_filename);
+	update_206fields();
+	update_header(NEW);
+	buff206.assign("<ics206>");
+	make_buff206();
 	write_206(def_206_filename);
 
 	using_ics206_template = false;
 	show_filename(def_206_filename);
+	return true;
 }
 
 void cb_206_save()
@@ -616,6 +731,10 @@ void cb_206_save()
 		cb_206_save_as();
 		return;
 	}
+	if (check_206fields()) update_header(CHANGED);
+	update_206fields();
+	buff206.assign(header("<ics206>"));
+	make_buff206();
 	write_206(def_206_filename);
 	using_ics206_template = false;
 }
