@@ -86,10 +86,10 @@ string ics309_preparer_date_time	= ":dtm:";
 string ics309_radio_net				= ":net:";
 string ics309_radio_operator		= ":opr:";
 
-string ics309_comm_msg				= ":msg[n]:"; // 34
-string ics309_comm_to				= ":to[n]:"; // 34
-string ics309_comm_from				= ":fm[n]:"; // 34
-string ics309_comm_time				= ":tm[n]:"; // 34
+string ics309_comm_msg				= ":msg[n]:"; // 60
+string ics309_comm_to				= ":to[n]:"; // 60
+string ics309_comm_from				= ":fm[n]:"; // 60
+string ics309_comm_time				= ":tm[n]:"; // 60
 
 string s309_incident;
 string s309_date_fm;
@@ -101,10 +101,10 @@ string s309_preparer_date_time;
 string s309_radio_net;
 string s309_radio_operator;
 
-string s309_comm_time[34];
-string s309_comm_from[34];
-string s309_comm_msg[34];
-string s309_comm_to[34];
+string s309_comm_time[60];
+string s309_comm_from[60];
+string s309_comm_msg[60];
+string s309_comm_to[60];
 
 // =====================================================================
 
@@ -153,7 +153,7 @@ void clear_309fields()
 	s309_radio_net.clear();
 	s309_radio_operator.clear();
 
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		s309_comm_msg[i].clear();
 		s309_comm_to[i].clear();
 		s309_comm_from[i].clear();
@@ -180,7 +180,7 @@ bool check_309fields()
 		return true;
 	if (s309_preparer_date_time != txt_309_preparer_date_time->value())
 		return true;
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		if (s309_comm_time[i] != txt_309_comm_time[i]->value())
 			return true;
 		if (s309_comm_msg[i] != txt_309_comm_msg[i]->value())
@@ -204,7 +204,7 @@ void update_309fields()
 	s309_radio_net = txt_309_radio_net->value();
 	s309_radio_operator = txt_309_radio_operator->value();
 	s309_preparer_date_time = txt_309_preparer_date_time->value();
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		s309_comm_time[i] = txt_309_comm_time[i]->value();
 		s309_comm_from[i] = txt_309_comm_from[i]->value();
 		s309_comm_to[i] = txt_309_comm_to[i]->value();
@@ -224,7 +224,7 @@ void update_309form()
 	txt_309_radio_operator->value(s309_radio_operator.c_str());
 	txt_309_preparer_date_time->value(s309_preparer_date_time.c_str());
 
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		txt_309_comm_time[i]->value(s309_comm_time[i].c_str());
 		txt_309_comm_to[i]->value(s309_comm_to[i].c_str());
 		txt_309_comm_from[i]->value(s309_comm_from[i].c_str());
@@ -247,14 +247,16 @@ string &ics309_nn(string & subst, int n)
 	size_t pos = ics.find("[");
 	if (pos == string::npos) return garbage;
 	pos++;
-	if (n < 10)
-		ics[pos] = '0' + n;
-	else {
-		ics[pos] = n > 29 ? '3' : n > 19 ? '2' : '1';
-		ics[pos+1] = '0' + n % 10;
-		ics[pos+2] = ']';
-		ics += ':';
-	}
+
+	ics[pos] =	n > 49 ? '5' :
+				n > 39 ? '4' :
+				n > 29 ? '3' :
+				n > 19 ? '2' :
+				n > 9  ? '1' : '0';
+	ics[pos+1] = '0' + n % 10;
+	ics[pos+2] = ']';
+	ics += ':';
+
 	return ics;
 }
 
@@ -272,7 +274,7 @@ void make_buff309(bool compress = false)
 	mbuff.append( lineout( ics309_radio_net, s309_radio_net ) );
 	mbuff.append( lineout( ics309_radio_operator, s309_radio_operator ) );
 
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		mbuff.append( lineout( ics309_nn( ics309_comm_time, i ), s309_comm_time[i] ) );
 		mbuff.append( lineout( ics309_nn( ics309_comm_to, i ),     s309_comm_to[i] ) );
 		mbuff.append( lineout( ics309_nn( ics309_comm_from, i ),     s309_comm_from[i] ) );
@@ -297,7 +299,7 @@ void read_309_buffer(string data)
 	s309_radio_net = findstr( data, ics309_radio_net );
 	s309_radio_operator  = findstr( data, ics309_radio_operator );
 
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		s309_comm_time[i]    = findstr( data, ics309_nn( ics309_comm_time, i ) );
 		s309_comm_to[i]      = findstr( data, ics309_nn( ics309_comm_to, i ) );
 		s309_comm_from[i]    = findstr( data, ics309_nn( ics309_comm_from, i ) );
@@ -580,7 +582,7 @@ void cb_309_html()
 	replacestr(form309, ics309_radio_net, s309_radio_net );
 	replacestr(form309, ics309_radio_operator, s309_radio_operator );
 
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		replacestr(form309, ics309_nn( ics309_comm_time, i ),
 			s309_comm_time[i].empty() ? empty : s309_comm_time[i] );
 		replacestr(form309, ics309_nn( ics309_comm_to, i ), 
@@ -624,7 +626,7 @@ void cb_309_textout()
 	replacestr(form309, ics309_radio_net, s309_radio_net );
 	replacestr(form309, ics309_radio_operator, s309_radio_operator );
 
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		replacestr(form309, ics309_nn( ics309_comm_time, i ), s309_comm_time[i] );
 		replacestr(form309, ics309_nn( ics309_comm_msg, i ), s309_comm_msg[i] );
 		replacestr(form309, ics309_nn( ics309_comm_to, i ), s309_comm_to[i] );
@@ -669,7 +671,7 @@ void ics309_csv(Fl_Widget *w, void *d)
 	cvs_text.append("\n");
 	cvs_text.append("COMM_TIME,COMM_TO,COMM_FM,COMM_MSG\n");
 	
-	for (int i = 0; i < 34; i++) {
+	for (int i = 0; i < 60; i++) {
 		cvs_text.append("\"").append(s309_comm_time[i]).append("\",");
 		cvs_text.append("\"").append(s309_comm_to[i]).append("\",");
 		cvs_text.append("\"").append(s309_comm_from[i]).append("\",");
