@@ -125,7 +125,7 @@ extern void cb_html();
 extern void cb_html_fcopy();
 extern void cb_folders();
 
-extern void open_url(const char* url);
+extern void open_url(const char* url, int folder = 0);
 
 extern void cb_arl();
 extern void cb_arl_cancel();
@@ -141,7 +141,7 @@ extern void closeoptions();
 
 extern void remove_spaces_from_filename(string &fname);
 extern char *szTime(int typ = 0);
-extern char *szDate();
+extern char *szDate(int df = -1);
 extern char *szAbbrevDate();
 extern char *szDateTime();
 extern char *szMarsDateTime();
@@ -634,7 +634,7 @@ extern void cb_custom_open();
 extern void write_custom(string s);
 extern bool cb_custom_save_as();
 extern void cb_custom_save();
-extern void cb_custom_html();
+extern void cb_custom_html(bool);
 extern void cb_custom_msg_type();
 extern void cb_custom_textout();
 extern void cb_custom_export_data(bool);
