@@ -69,6 +69,9 @@ extern const char blank_txt_template[];
 extern const char csv_html_template[];
 extern const char csv_txt_template[];
 
+extern const char custom_html_template[];
+extern const char custom_txt_template[];
+
 extern const char baddata_html_template[];
 
 extern const char mars_daily_html_template[];
