@@ -1,32 +1,22 @@
-// =====================================================================
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// parse_xml.cxx
+// This file is part of flmsg
 //
-// Author: Dave Freese, W1HKJ
-// Copyright: 2010
+// flrig is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
 //
-// Qforms import / export
-//
-// This software is distributed in the hope that it will be useful,
+// flrig is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  It is
-// copyright under the GNU General Public License.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
-//
-// =====================================================================
-
-//########################################################################
-//
-//  Qforms import / export
-//
-//  copywrite David Freese, w1hkj@w1hkj.com
-//
-//########################################################################
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #include "config.h"
 #include "flmsg_config.h"
@@ -586,6 +576,7 @@ bool qform_ics_import(string fname)
 	fseek (xmlfile, 0, SEEK_SET);
 	retval = fread (buff, filesize, 1, xmlfile);
 	fclose (xmlfile);
+	if (retval != 1) return false;
 
 	ics_pmode = HICS_TO;
 	clear_ics_xml();
@@ -1066,16 +1057,16 @@ void transfer_rgfields()
 	}
 
 	if (rg_xml_exer == "yes") {
-		if (rg_xml_prec.find("ROUTINE") != string::npos) sel_rg_prec->value(4);
-		else if (rg_xml_prec.find("WELFARE") != string::npos) sel_rg_prec->value(5);
-		else if (rg_xml_prec.find("PRIORITY") != string::npos) sel_rg_prec->value(6);
-		else if (rg_xml_prec.find("EMERGENCY") != string::npos) sel_rg_prec->value(7);
+		if (rg_xml_prec.find("ROUTINE") != string::npos) sel_rg_prec->index(4);
+		else if (rg_xml_prec.find("WELFARE") != string::npos) sel_rg_prec->index(5);
+		else if (rg_xml_prec.find("PRIORITY") != string::npos) sel_rg_prec->index(6);
+		else if (rg_xml_prec.find("EMERGENCY") != string::npos) sel_rg_prec->index(7);
 		else sel_rg_prec->value(0);
 	} else {
-		if (rg_xml_prec.find("ROUTINE") != string::npos) sel_rg_prec->value(0);
-		else if (rg_xml_prec.find("WELFARE") != string::npos) sel_rg_prec->value(1);
-		else if (rg_xml_prec.find("PRIORITY") != string::npos) sel_rg_prec->value(2);
-		else if (rg_xml_prec.find("EMERGENCY") != string::npos) sel_rg_prec->value(3);
+		if (rg_xml_prec.find("ROUTINE") != string::npos) sel_rg_prec->index(0);
+		else if (rg_xml_prec.find("WELFARE") != string::npos) sel_rg_prec->index(1);
+		else if (rg_xml_prec.find("PRIORITY") != string::npos) sel_rg_prec->index(2);
+		else if (rg_xml_prec.find("EMERGENCY") != string::npos) sel_rg_prec->index(3);
 		else sel_rg_prec->value(0);
 	}
 	
@@ -1126,6 +1117,7 @@ bool qform_rg_import(string fname)
 	fseek (xmlfile, 0, SEEK_SET);
 	retval = fread (buff, filesize, 1, xmlfile);
 	fclose (xmlfile);
+	if (retval != 1) return false;
 
 	rg_pmode = FILED;
 	clear_rg_xml();
